==> chgksuite-0.8.1.tar.gz: chgksuite-0.8.1/history.md <==
# What’s new

## v0.8.1

Исправлена пара багов предыдущей версии, в том числе баг, из-за которого не публиковалась навигация в ЖЖ.

## v0.8.0

Сильно улучшено создание презентаций, теперь картинки расставляются сами, лучше определяется размер шрифта в зависимости от длины текста. Презентации после создания готовы к употреблению и не требуют дополнительного редактирования (но это не точно). Для презентаций можно задать свой шаблон оформления.

Добавлена поддержка мультиязычности: теперь можно подложить свои файлы конфигурации с другими названиями полей не только для парсинга в формат 4s, но и для экспорта в docx/ЖЖ. Для примера поддержан украинский язык.

Локальное переопределение названий полей: если в данном конкретном вопросе какое-то поле хочется переименовать (например, «Вопрос» в «Загадка» или «Автор» в «Авторка»), можно написать в 4s что-то типа `? !!Загадка Один журналист отмечает...` или `@ !!Авторка Мария Подрядчикова`, и эти названия сохранятся в выходном файле. Слово «авторка» при парсинге автоматически сохраняется в качестве локального переопределения.

Парсер научился сохранять в 4s номер вопроса. По умолчанию сохраняется только нулевой вопрос, это поведение можно изменить (сохранять все номера или не сохранять никакие).

При экспорте в docx, pptx и ЖЖ возле предлогов и союзов теперь в правильных местах ставятся неразрывные пробелы. При экспорте в docx теперь есть номера страниц, а туры начинаются с новой страницы.

## v0.7.0

Добавлено экспериментальное создание презентаций для онлайн-игр. Выберите pptx в меню форматов экспорта. Пока что генерируемые презентации не готовы к употреблению, их нужно редактировать руками (расставлять картинки, обрабатывать дополнительно дуплеты и т.д.)

Улучшена обработка групп друзей при выкладке в ЖЖ.

Теперь тексты вопросов и комментариев при экспорте в docx не разбиваются разрывом страницы.

## v0.6.3
Теперь поправил аналогичный баг, который не давал композить файлы в другой папке, если они содержали изображения. ([коммит](https://gitlab.com/peczony/chgksuite/-/commit/5abe61cbb10e35f4b30bf216e2099d262fc3357f))

Исправил баг, при котором падал экспорт в базу, если поле «Незачёт» содержало список. ([коммит](https://gitlab.com/peczony/chgksuite/-/commit/1e0a27f0a63baf87749783944a4fb69ebd083bff))

Спасибо Рузелю Халиуллину и Станиславу Утикееву за багрепорты.

## v0.6.2

Исправил баг, который присутствовал с 0.6.0 — распарсить можно было только файл, который лежит в той же папке, что и chgksuite. ([коммит](https://gitlab.com/peczony/chgksuite/-/commit/36486f32ba36077e9645e6a2b3def7593374bf8b))

## v0.6.1

Из-за бага всё, связанное с трелло, не работало. Пофиксил. ([коммит](https://gitlab.com/peczony/chgksuite/-/commit/9aaf6ffbcd478187ed103dadb3ffe17dc63f449c))

На системах, где не установлен тех, падал тест. Это глупо. Распилил тест на два, тот, что связан с техом, по умолчанию пропускается, если есть желание его протестировать, можно запустить с ключом `--tex`. ([коммит](https://gitlab.com/peczony/chgksuite/-/commit/0a8817b9b6deea17385def5a62d905e9c5a31ad2))

Теперь можно при картинках явно указывать, в каких единицах заданы ширина и высота. ([коммит](https://gitlab.com/peczony/chgksuite/-/commit/288a1a6e24036238481a0813d6c808f12d5d1a83))

## v0.6.0

Теперь chgksuite есть на PYPI: https://pypi.org/project/chgksuite

chgksuite научилась добавлять навигацию по турам в ЖЖ-посты.

Исправлен баг в логировании.

Теперь в интерфейсе и в консоли выводится версия программы.

## v0.5.8

При выкладывании в Базу теперь происходит автоматический ресайз картинок, ограничивая максимальную сторону 600 пикселями — это решает распространённую проблему, когда картинка хорошего качества в Базе вылезала за границы экрана.

Поправил баг, когда при парсинге 4s могли создаваться списки из одного элемента.

Между вопросами в вордовском экспорте теперь по умолчанию два переноса строки, а не один. Это можно отключить.

## v0.5.7

Дофиксил предыдущий баг — были проблемы в работе с Трелло.  
В вордовском темплейте изменил дефолтный шрифт с Камбрии на Ариал.  
Под Маком теперь собираю системным питоном, а не анакондовским — иногда могут быть не видны надписи на кнопках и элементах интерфейса (говорят, ресайз окна помогает), зато под Mojave не крэшится :)  
Под Виндоус не работал парсинг текстовых файлов в формате Базы, теперь работает.  
Пофиксил баг #29 — когда в заголовке тура число идёт сначала, а слово «тур» потом, разделитель туров при парсинге ставился в неправильное место.  
Прибрался по мелочи.

## v0.5.6

Пофиксил баг в последнем релизе, когда ничего не работало из-за неправильного определения пути к текущей папке в PyInstaller

## v0.5.5

Новый GUI, смысл которого в том, чтобы он был во взаимно однозначном соответствии с аргументами командной строки. Достигается это тем, что GUI автоматически генерируется из кода, описывающего CLI. Попутно это фиксит регрессию в прошлой версии, касающуюся того, что при запуске парсинга docx-файла из GUI некорректно обрабатывались ссылки.

Мелкий фикс #27 (Александр Потапенко)

## v0.5.4

Закоммитил забытый в прошлом релизе фикс #18

## v0.5.3

(#16, #19, #22) Добавлен выбор стратегии обработки ссылок при парсинге docx (`--links`). Дефолтное значение, в отличие от поведения предыдущих версий — `unwrap`. Значение `old` воспроизводит предыдущее поведение.

(#21) Улучшен вывод в Базу: идущие подряд «meta»/«Инфо» склеиваю в один, автоматически оформляю нулевые вопросы отдельными турами (в Базе нельзя иначе).

Исправлены баги #18, #25.

## v0.5.1–0.5.2

Исправлены баги в экспорте Базы (#13, #14, #15).

## v0.5

Добавлены:

- экспорт в Базу (`compose base`)
- экспорт на реддит (`compose redditmd`)

Исправлены баги в трелло-экспорте (Евгений Миротин).

## v0.4

Добавлены:

- возможность при экспорте своей игры выгрузить только ответы (`--onlyanswers`, полезно для проверки письменного свояка)
- экспериментальная недокументированная поддержка квизбола в экспорте трелло (`--qb`)
- экспериментальная недокументированная поддержка групп друзей при экспорте в ЖЖ ([коммит](https://gitlab.com/peczony/chgksuite/commit/495b154bdf4012d4164c8db48e7685eec6fe61be))

Исправлены баги в трелло- и латех-экспорте.

## v0.3rc1

Добавлены:

- логирование
- парсинг файлов в формате Базы (Аркадий Илларионов)
- поддержка работы с Trello в интерфейсе
- поддержка работы с произвольными регулярными выражениями для парсинга полей вместо заранее заведённых авторских
- поддержка python3
- файлы requirements и requirements_dev для работы с virtualenv

Исправлено множество багов, которые лень перечислять

## v0.2rc2

- Добавлена возможность парсить сразу целую папку.
- Добавлена возможность при парсинге подставлять вместо автора вопроса имя файла, если автор не указан.
- Добавлен экспорт вопросов в Trello (отдельный Python-скрипт, без поддержки в GUI и бинарных сборках).
- Автоматически определяются заголовок и дата пакета.
- Теперь в ЖЖ можно одним кликом выложить весь пакет: есть возможность автоматически разбить на туры и добавить пост про общие впечатления. К сожалению, выкладка в ЖЖ стала медленнее: добавлены паузы, чтобы соблюдать рейт-лимиты жежешного антиспама.
- Исправлен баг с дефисом-минусом методом отрывания функциональности автоматической расстановки символов «–» (короткое тире) и «−» (минус), теперь автоматически расставляются только длинные тире и кавычки. Возможно, в будущем после доработки фичу верну.
- Исправлены все остальные баги из v0.2rc1, кроме некорректного распознавания формата Базы.

## v0.2rc1

- Вместо отдельных файлов `chgk_parser` и `chgk_composer` появилась единая точка входа — `chgksuite`. Для использования в консоли вместо `chgk_parser` теперь нужно писать `chgksuite parse`, вместо `chgk_composer` — `chgksuite compose`, в остальном без изменений.
- Больше нет необходимости копировать файлы `chgksuite` в каждый каталог с файлами вопросов, вопросы и `chgksuite` могут жить отдельно.
- Размеры картинок определяются автоматически (слишком большие уменьшаются, слишком маленькие увеличиваются).
- Запоминается последний рабочий каталог.
- В обоих режимах (импорт, экспорт) появились предупреждения об ошибках вида `WARNING: question (текст вопроса) lacks the following fields: source, ...` — с перечислением отсутствующих, по мнению парсера, полей.
- Улучшена поддержка файлов с кириллическими именами под Windows (но лучше всё равно их не используйте).
- Добавлен импорт пакета из Trello (отдельный Python-скрипт, без поддержки в GUI и бинарных сборках).
- Добавлено автоматическое определение кодировки txt-файлов.
- Рабочий каталог chgksuite больше не засоряется временными файлами при экспорте в tex.
- Появились тесты.
- Исправлено множество багов (например, баг, когда при использовании бинарной сборки под Windows не выкладывались в ЖЖ пакеты с картинками)

Известные неисправленные баги:

- Файлы с символом дефиса-минуса `-` в имени или пути могут распознаваться и создаваться некорректно.
- Текстовые файлы в формате Базы Вопросов распознаются некорректно.
- Дуплеты и блицы распознаются некорректно.
- Вопросы, содержащие последовательности символов «вопрос.» и «ответ.», распознаются некорректно.

==> chgksuite-0.8.2.tar.gz: chgksuite-0.8.2/history.md <==
# What’s new

## v0.8.2

Исправлено падение под Windows из-за несовпадения дефолтной кодировки (теперь все файлы читаются в utf-8).

## v0.8.1

Исправлена пара багов предыдущей версии, в том числе баг, из-за которого не публиковалась навигация в ЖЖ.

## v0.8.0

Сильно улучшено создание презентаций, теперь картинки расставляются сами, лучше определяется размер шрифта в зависимости от длины текста. Презентации после создания готовы к употреблению и не требуют дополнительного редактирования (но это не точно). Для презентаций можно задать свой шаблон оформления.

Добавлена поддержка мультиязычности: теперь можно подложить свои файлы конфигурации с другими названиями полей не только для парсинга в формат 4s, но и для экспорта в docx/ЖЖ. Для примера поддержан украинский язык.

Локальное переопределение названий полей: если в данном конкретном вопросе какое-то поле хочется переименовать (например, «Вопрос» в «Загадка» или «Автор» в «Авторка»), можно написать в 4s что-то типа `? !!Загадка Один журналист отмечает...` или `@ !!Авторка Мария Подрядчикова`, и эти названия сохранятся в выходном файле. Слово «авторка» при парсинге автоматически сохраняется в качестве локального переопределения.

Парсер научился сохранять в 4s номер вопроса. По умолчанию сохраняется только нулевой вопрос, это поведение можно изменить (сохранять все номера или не сохранять никакие).

При экспорте в docx, pptx и ЖЖ возле предлогов и союзов теперь в правильных местах ставятся неразрывные пробелы. При экспорте в docx теперь есть номера страниц, а туры начинаются с новой страницы.

## v0.7.0

Добавлено экспериментальное создание презентаций для онлайн-игр. Выберите pptx в меню форматов экспорта. Пока что генерируемые презентации не готовы к употреблению, их нужно редактировать руками (расставлять картинки, обрабатывать дополнительно дуплеты и т.д.)

Улучшена обработка групп друзей при выкладке в ЖЖ.

Теперь тексты вопросов и комментариев при экспорте в docx не разбиваются разрывом страницы.

## v0.6.3
Теперь поправил аналогичный баг, который не давал композить файлы в другой папке, если они содержали изображения. ([коммит](https://gitlab.com/peczony/chgksuite/-/commit/5abe61cbb10e35f4b30bf216e2099d262fc3357f))

Исправил баг, при котором падал экспорт в базу, если поле «Незачёт» содержало список. ([коммит](https://gitlab.com/peczony/chgksuite/-/commit/1e0a27f0a63baf87749783944a4fb69ebd083bff))

Спасибо Рузелю Халиуллину и Станиславу Утикееву за багрепорты.

## v0.6.2

Исправил баг, который присутствовал с 0.6.0 — распарсить можно было только файл, который лежит в той же папке, что и chgksuite. ([коммит](https://gitlab.com/peczony/chgksuite/-/commit/36486f32ba36077e9645e6a2b3def7593374bf8b))

## v0.6.1

Из-за бага всё, связанное с трелло, не работало. Пофиксил. ([коммит](https://gitlab.com/peczony/chgksuite/-/commit/9aaf6ffbcd478187ed103dadb3ffe17dc63f449c))

На системах, где не установлен тех, падал тест. Это глупо. Распилил тест на два, тот, что связан с техом, по умолчанию пропускается, если есть желание его протестировать, можно запустить с ключом `--tex`. ([коммит](https://gitlab.com/peczony/chgksuite/-/commit/0a8817b9b6deea17385def5a62d905e9c5a31ad2))

Теперь можно при картинках явно указывать, в каких единицах заданы ширина и высота. ([коммит](https://gitlab.com/peczony/chgksuite/-/commit/288a1a6e24036238481a0813d6c808f12d5d1a83))

## v0.6.0

Теперь chgksuite есть на PYPI: https://pypi.org/project/chgksuite

chgksuite научилась добавлять навигацию по турам в ЖЖ-посты.

Исправлен баг в логировании.

Теперь в интерфейсе и в консоли выводится версия программы.

## v0.5.8

При выкладывании в Базу теперь происходит автоматический ресайз картинок, ограничивая максимальную сторону 600 пикселями — это решает распространённую проблему, когда картинка хорошего качества в Базе вылезала за границы экрана.

Поправил баг, когда при парсинге 4s могли создаваться списки из одного элемента.

Между вопросами в вордовском экспорте теперь по умолчанию два переноса строки, а не один. Это можно отключить.

## v0.5.7

Дофиксил предыдущий баг — были проблемы в работе с Трелло.  
В вордовском темплейте изменил дефолтный шрифт с Камбрии на Ариал.  
Под Маком теперь собираю системным питоном, а не анакондовским — иногда могут быть не видны надписи на кнопках и элементах интерфейса (говорят, ресайз окна помогает), зато под Mojave не крэшится :)  
Под Виндоус не работал парсинг текстовых файлов в формате Базы, теперь работает.  
Пофиксил баг #29 — когда в заголовке тура число идёт сначала, а слово «тур» потом, разделитель туров при парсинге ставился в неправильное место.  
Прибрался по мелочи.

## v0.5.6

Пофиксил баг в последнем релизе, когда ничего не работало из-за неправильного определения пути к текущей папке в PyInstaller

## v0.5.5

Новый GUI, смысл которого в том, чтобы он был во взаимно однозначном соответствии с аргументами командной строки. Достигается это тем, что GUI автоматически генерируется из кода, описывающего CLI. Попутно это фиксит регрессию в прошлой версии, касающуюся того, что при запуске парсинга docx-файла из GUI некорректно обрабатывались ссылки.

Мелкий фикс #27 (Александр Потапенко)

## v0.5.4

Закоммитил забытый в прошлом релизе фикс #18

## v0.5.3

(#16, #19, #22) Добавлен выбор стратегии обработки ссылок при парсинге docx (`--links`). Дефолтное значение, в отличие от поведения предыдущих версий — `unwrap`. Значение `old` воспроизводит предыдущее поведение.

(#21) Улучшен вывод в Базу: идущие подряд «meta»/«Инфо» склеиваю в один, автоматически оформляю нулевые вопросы отдельными турами (в Базе нельзя иначе).

Исправлены баги #18, #25.

## v0.5.1–0.5.2

Исправлены баги в экспорте Базы (#13, #14, #15).

## v0.5

Добавлены:

- экспорт в Базу (`compose base`)
- экспорт на реддит (`compose redditmd`)

Исправлены баги в трелло-экспорте (Евгений Миротин).

## v0.4

Добавлены:

- возможность при экспорте своей игры выгрузить только ответы (`--onlyanswers`, полезно для проверки письменного свояка)
- экспериментальная недокументированная поддержка квизбола в экспорте трелло (`--qb`)
- экспериментальная недокументированная поддержка групп друзей при экспорте в ЖЖ ([коммит](https://gitlab.com/peczony/chgksuite/commit/495b154bdf4012d4164c8db48e7685eec6fe61be))

Исправлены баги в трелло- и латех-экспорте.

## v0.3rc1

Добавлены:

- логирование
- парсинг файлов в формате Базы (Аркадий Илларионов)
- поддержка работы с Trello в интерфейсе
- поддержка работы с произвольными регулярными выражениями для парсинга полей вместо заранее заведённых авторских
- поддержка python3
- файлы requirements и requirements_dev для работы с virtualenv

Исправлено множество багов, которые лень перечислять

## v0.2rc2

- Добавлена возможность парсить сразу целую папку.
- Добавлена возможность при парсинге подставлять вместо автора вопроса имя файла, если автор не указан.
- Добавлен экспорт вопросов в Trello (отдельный Python-скрипт, без поддержки в GUI и бинарных сборках).
- Автоматически определяются заголовок и дата пакета.
- Теперь в ЖЖ можно одним кликом выложить весь пакет: есть возможность автоматически разбить на туры и добавить пост про общие впечатления. К сожалению, выкладка в ЖЖ стала медленнее: добавлены паузы, чтобы соблюдать рейт-лимиты жежешного антиспама.
- Исправлен баг с дефисом-минусом методом отрывания функциональности автоматической расстановки символов «–» (короткое тире) и «−» (минус), теперь автоматически расставляются только длинные тире и кавычки. Возможно, в будущем после доработки фичу верну.
- Исправлены все остальные баги из v0.2rc1, кроме некорректного распознавания формата Базы.

## v0.2rc1

- Вместо отдельных файлов `chgk_parser` и `chgk_composer` появилась единая точка входа — `chgksuite`. Для использования в консоли вместо `chgk_parser` теперь нужно писать `chgksuite parse`, вместо `chgk_composer` — `chgksuite compose`, в остальном без изменений.
- Больше нет необходимости копировать файлы `chgksuite` в каждый каталог с файлами вопросов, вопросы и `chgksuite` могут жить отдельно.
- Размеры картинок определяются автоматически (слишком большие уменьшаются, слишком маленькие увеличиваются).
- Запоминается последний рабочий каталог.
- В обоих режимах (импорт, экспорт) появились предупреждения об ошибках вида `WARNING: question (текст вопроса) lacks the following fields: source, ...` — с перечислением отсутствующих, по мнению парсера, полей.
- Улучшена поддержка файлов с кириллическими именами под Windows (но лучше всё равно их не используйте).
- Добавлен импорт пакета из Trello (отдельный Python-скрипт, без поддержки в GUI и бинарных сборках).
- Добавлено автоматическое определение кодировки txt-файлов.
- Рабочий каталог chgksuite больше не засоряется временными файлами при экспорте в tex.
- Появились тесты.
- Исправлено множество багов (например, баг, когда при использовании бинарной сборки под Windows не выкладывались в ЖЖ пакеты с картинками)

Известные неисправленные баги:

- Файлы с символом дефиса-минуса `-` в имени или пути могут распознаваться и создаваться некорректно.
- Текстовые файлы в формате Базы Вопросов распознаются некорректно.
- Дуплеты и блицы распознаются некорректно.
- Вопросы, содержащие последовательности символов «вопрос.» и «ответ.», распознаются некорректно.
